@@ -109,7 +109,7 @@ BaseDictionaryView = KS.extend(BaseSvodView, { });
                 } else if (field.indexOf("PRINT_URL") >= 0) {
                     var urlsArray = args[0][0][field];
                     Ext.each(urlsArray, function (url) {
-                        view.openUrl(url);
+                        view.downloadFile(url);
                     });
                 }
             }
