@@ -303,13 +303,13 @@ SavedFormBatchExportView = KS.extend(BaseSvodView, {});
     KS.apply(viewClass, {
         loadSettingsGrid: function(){
             var checkedRows = this.formsGrid.getCheckedRows(),
-                checkedCodes = [];
+                formsLinks = [];
             Ext.each(checkedRows, function(row){
-                checkedCodes.push(KS.Grid.getAnyCase(row, "LINK_FORM"));
+                formsLinks.push(KS.Grid.getAnyCase(row, "LINK_FORM"));
             })
             this.serverCall({
                 method: 'LoadSettingsGrid',
-                params: [checkedCodes]
+                params: [formsLinks]
             });
         },
 
@@ -415,11 +415,11 @@ SavedFormBatchExportView = KS.extend(BaseSvodView, {});
             }
         },
 
-        changePrintStrCell: function(closeCode){
+        changePrintStrCell: function(linkForm){
             var view = this;
             view.serverCall({
                 method: 'ClearPrintTemplate',
-                params: [closeCode],
+                params: [linkForm],
                 success: function(result){
                     if (result)
                         view.settingsGrid.reload();
@@ -682,10 +682,10 @@ SavedFormBatchExportView = KS.extend(BaseSvodView, {});
     });
 }(SavedFormBatchExportView.prototype));
 
-function changePrintStrCell(viewId, closeCode) {
+function changePrintStrCell(viewId, linkForm) {
     var view = KS.getView(viewId);
     if (view)
-        view.changePrintStrCell(closeCode);
+        view.changePrintStrCell(linkForm);
 }
 
 // ============= RENDERERS =======================
@@ -695,9 +695,9 @@ function printStrRenderer(value, metadata, record, rowIndex, colIndex, store) {
     metadata.css += ' sidewall-dict-cell';
 
     var grid = store.grid,
-        closeCode = KS.Grid.getAnyCase(record, grid.closeCode),
+        linkForm = KS.Grid.getAnyCase(record, "LINK_FORM"),
         viewId = grid.parentView.viewID,
-        cleanBtn = '<img src="PlatformHandler.axd?icon=clean.png" onclick="changePrintStrCell(\'' + viewId + '\',\'' + closeCode + '\')" style="vertical-align: middle;"/>';
+        cleanBtn = '<img src="PlatformHandler.axd?icon=clean.png" onclick="changePrintStrCell(\'' + viewId + '\',\'' + linkForm + '\')" style="vertical-align: middle;"/>';
     
     return cleanBtn + value;
 }
