@@ -224,14 +224,18 @@ KS.apply(KS,
 
         processReportHyperLink: function (e, viewId) {
             try {
-                var view = KS.getView(viewId),
-                    a = e.target || e.srcElement;
-                if (view && a) {
-                    view.serverCall({
-                        method: 'ProcessReportHyperLink',
-                        params: [a.href + ''],
-                        waitMessage: 'Обработка ссылки ...'
-                    });
+                var a = e.target || e.srcElement;
+                if (Ext.isEmpty(a.hash) || !a.hash.startsWith('#')) {
+                    e.preventDefault();
+
+                    var view = KS.getView(viewId);
+                    if (view && a) {
+                        view.serverCall({
+                            method: 'ProcessReportHyperLink',
+                            params: [a.href + ''],
+                            waitMessage: 'Обработка ссылки ...'
+                        });
+                    }
                 }
             } catch (e) {
                 KS.msg('Ошибка перехода по ссылке');
